@@ -486,7 +486,7 @@ clearlooks_glossy_draw_progressbar_fill (cairo_t *cr,
 	cairo_pattern_destroy (pattern);
 
 	/* Draw the Strokes */
-	while (tile_pos <= width+x_step)
+	while (stroke_width > 0 && tile_pos <= width+x_step)
 	{
 		cairo_move_to (cr, stroke_width/2-x_step, 0);
 		cairo_line_to (cr, stroke_width-x_step,   0);
