@@ -1,50 +1,51 @@
-/* Redmond Engine
+/* Redmond95 - a cairo based GTK+ engine
  * Copyright (C) 2001 Red Hat, Inc.
+ * Copyright (C) 2006 Andrew Johnson <acjgenius@earthlink.net>
+ * Copyright (C) 2006-2007 Benjamin Berg <benjamin@sipsolutions.net>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * Project contact: <gnome-themes-list@gnome.org>
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
  *
- * Written by Owen Taylor <otaylor@redhat.com>
- * modified by Andrew Johnson <ajgenius@ajgenius.us>
- */
-#include "redmond_gtk2_engine.h"
-#include "redmond_gtk2_drawing.h"
-#include "redmond_gtk2_misc.h"
- 
-/***********************************************************************
  * Portions of the code based on/copied from the Bluecurve theme/engine, 
- *   License: GPL 
+ *   License: LGPL2+
  *   Copyright:
  *     Alexander Larsson <alexl@redhat.com>
  *     Garrett LeSage
  *     Owen Taylor <otaylor@redhat.com>
  *
  * Portions of the code based on/copied from the Metal theme/engine, 
- *   License: GPL 
+ *   License: LGPL2.1+
  *   Copyright:
  *     Randy Gordon, randy@integrand.com
  *     Owen Taylor <otaylor@redhat.com>
  *
  * Portions of the code based on/copied from the Smooth Engine,
- *   License: LGPL 
+ *   License: LGPL
  *   Copyright:
  *     Andrew Johnson <ajgenius@ajgenius.us
  *
- ***********************************************************************/
- 
- 
+ */
+
+
+#include "redmond_gtk2_engine.h"
+#include "redmond_gtk2_drawing.h"
+#include "redmond_gtk2_misc.h"
+
+
 /***********************************************
  * redmond_draw_vline -
  *  
@@ -677,6 +678,7 @@ redmond_draw_combobox_button (GtkStyle * style,
           gtk_paint_shadow (style, window, state_type, GTK_SHADOW_IN,
   		            area, widget, "entry", x - 2, y, width, height);
         }
+#ifndef GTK_DISABLE_DEPRECATED
       else if (ge_is_combo(widget))
         {
           GtkWidget *entry = widget;
@@ -689,7 +691,8 @@ redmond_draw_combobox_button (GtkStyle * style,
                parent_style = entry->style;
                parent_state = entry->state;
              }
-          else if (GE_IS_WIDGET(widget->parent))
+          else
+                if (GE_IS_WIDGET(widget->parent))
             {
                entry = widget->parent;
                gtk_widget_ensure_style(entry);
@@ -722,6 +725,9 @@ redmond_draw_combobox_button (GtkStyle * style,
 	 	              &clip, entry, "entry", x - 4, y, width + 2, height);
           }
         }
+#else
+#warning Disabling GtkCombo support because GTK_DISABLE_DEPRECATED is enabled.
+#endif
       else
         {
           GtkWidget *parent = widget;
@@ -790,6 +796,7 @@ redmond_draw_combobox_button (GtkStyle * style,
           gtk_paint_shadow (style, window, state_type, GTK_SHADOW_IN,
 	  		    area, widget, "entry", x + 2, y, width, height);
         }
+#ifndef GTK_DISABLE_DEPRECATED
       else if (ge_is_combo(widget))
         {
           GtkWidget *entry = widget;
@@ -820,6 +827,9 @@ redmond_draw_combobox_button (GtkStyle * style,
            gtk_paint_shadow (parent_style, window, parent_state, GTK_SHADOW_IN,
 			     area, entry, "entry", x + 2, y, width, height);
         }
+#else
+#warning Disabling GtkCombo support because GTK_DISABLE_DEPRECATED is enabled.
+#endif /* GTK_DISABLE_DEPRECATED */
       else
         {
           GtkWidget *parent = widget;
